@@ -9,6 +9,7 @@ logging.getLogger('sseclient').disabled = True
 logging.getLogger('urllib3.connectionpool').disabled = True
 
 
+
 rule_engine = RuleEngine.start_singleton("http://192.168.1.27:8080/", "C:\\workspace\\\\openhab_rules", "grro", "Stabilo33!")
 
 '''
@@ -16,6 +17,7 @@ for i in range(0, 10000):
     sleep(5)
     print("")
     for rule in rule_engine.rules:
-        print(str(rule))
+        print(str(rule.last_executions))
+
 '''
-sleep(1222222)
\ No newline at end of file
+sleep(390000)
\ No newline at end of file
